#include "stdafx.h"
#include "MyListView.h"

//- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
CMyListView::CMyListView() : CMyWindow(WC_LISTVIEW)
{
	INITCOMMONCONTROLSEX	sInitCommonControl;

	sInitCommonControl.dwSize	= sizeof(INITCOMMONCONTROLSEX);
	sInitCommonControl.dwICC	= ICC_LISTVIEW_CLASSES;

	InitCommonControlsEx(&sInitCommonControl);
}

//- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
CMyListView::~CMyListView()
{
}

//- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
BOOL CMyListView::SetExtendedStyle(DWORD dwMask, DWORD dwStyle)
{
	if (m_hWnd == NULL) return(FALSE);

	ListView_SetExtendedListViewStyleEx(m_hWnd, dwMask, dwStyle);

	return(TRUE);
}

//- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
int CMyListView::InsertColumn(UINT nColumnIndex, LPCWSTR pwzText, UINT nColumnWidth)
{
	LVCOLUMN	sColumn;

	if (m_hWnd == NULL) return(-2);
	if (pwzText == NULL) return(-3);

	sColumn.mask		= LVCF_TEXT | LVCF_WIDTH;
	sColumn.cx			= nColumnWidth;
	sColumn.pszText	= (LPWSTR)pwzText;

	return(ListView_InsertColumn(m_hWnd, nColumnIndex, &sColumn));
}

//- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
int CMyListView::SetColumnText(UINT nColumnIndex, LPCWSTR pwzText)
{
	LVCOLUMN	sColumn;

	if (m_hWnd == NULL) return(-2);
	if (pwzText == NULL) return(-3);

	sColumn.mask		= LVCF_TEXT;
	sColumn.pszText	= (LPWSTR)pwzText;

	return(ListView_SetColumn(m_hWnd, nColumnIndex, &sColumn));
}

//- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
int CMyListView::SetItemText(int nItemIndex, UINT nSubItemIndex, LPCWSTR pwzText)
{
	LVITEM	sItem;

	if (m_hWnd == NULL) return(-2);
	if (pwzText == NULL) return(-3);
	if (nItemIndex < 0) return(nItemIndex);

	sItem.mask		= LVIF_TEXT;
	sItem.iItem		= nItemIndex;
	sItem.iSubItem	= nSubItemIndex;
	sItem.pszText	= (LPWSTR)pwzText;

	/*
	if (nSubItemIndex == 0) return(ListView_InsertItem(m_hWnd, &sItem));
	else 
	*/
	return(ListView_SetItem(m_hWnd, &sItem));
}

//- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
int CMyListView::InsertItem(int nItemIndex, LPCWSTR pwzText, UINT nIconIndex)
{
	LVITEM	sItem;

	if (m_hWnd == NULL) return(-2);
	if (pwzText == NULL) return(-3);
	if (nItemIndex < 0) return(nItemIndex);

	sItem.mask		= LVIF_TEXT | LVIF_IMAGE;
	sItem.iItem		= nItemIndex;
	sItem.iSubItem	= 0;
	sItem.pszText	= (LPWSTR)pwzText;
	sItem.iImage	= nIconIndex;

	return(ListView_InsertItem(m_hWnd, &sItem));

	/*
	if (nSubItemIndex == 0) return(ListView_InsertItem(m_hWnd, &sItem));
	else return(ListView_SetItem(m_hWnd, &sItem));
	*/
}

//- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
int CMyListView::InsertItem(int nItemIndex, LPCWSTR pwzText, UINT nIconIndex, LPVOID pParam)
{	
	LVITEM	sItem;

	if (m_hWnd == NULL) return(-2);
	if (pwzText == NULL) return(-3);
	if (nItemIndex < 0) return(nItemIndex);

	sItem.mask		= LVIF_TEXT | LVIF_IMAGE | LVIF_PARAM;
	sItem.iItem		= nItemIndex;
	sItem.iSubItem	= 0;
	sItem.pszText	= (LPWSTR)pwzText;
	sItem.iImage	= nIconIndex;
	sItem.lParam	= (LPARAM)pParam;

	return(ListView_InsertItem(m_hWnd, &sItem));
	
	/*
	if (nSubItemIndex == 0) return(ListView_InsertItem(m_hWnd, &sItem));
	else return(ListView_SetItem(m_hWnd, &sItem));
	*/
}

//- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
int CMyListView::GetItemCount()
{
	if (m_hWnd == NULL) return(0);
	else return(ListView_GetItemCount(m_hWnd));
}

//- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
UINT CMyListView::GetSelectedCount()
{
	if (m_hWnd == NULL) return(0);
	else return(ListView_GetSelectedCount(m_hWnd));
}

//- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
UINT CMyListView::GetItemState(int nIndex, UINT nMask)
{
	if (m_hWnd == NULL) return(0);
	else return(ListView_GetItemState(m_hWnd, nIndex, nMask));
}

//- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
BOOL CMyListView::GetItem(LPLVITEM psItem)
{
	if (psItem == NULL) return(FALSE);
	if (m_hWnd == NULL) return(FALSE);

	return(ListView_GetItem(m_hWnd, psItem));
}

//- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
BOOL CMyListView::DeleteAllItems()
{
	if (m_hWnd == NULL) return(FALSE);

	return(ListView_DeleteAllItems(m_hWnd));
}

//- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
BOOL CMyListView::SortItems(PFNLVCOMPARE pfnCompare, LPARAM lParamSort)
{
	if (m_hWnd == NULL) return(FALSE);

	return(ListView_SortItems(m_hWnd, pfnCompare, lParamSort));
}
